]> diplodocus.org Git - nmh/blobdiff - h/utils.h
Improve POP SASL error handling
[nmh] / h / utils.h
index 7cb96efdecb8f8f1905a2bdf53804fd7e2538811..4df5e1565dac062f581b9f77ba166b1a41e53157 100644 (file)
--- a/h/utils.h
+++ b/h/utils.h
@@ -86,7 +86,7 @@ bool contains8bit(const char *start, const char *end);
  * See if file has any 8-bit bytes.
  * Arguments include:
  *
- * fd          - file descriptor
+ * fd          - file descriptor
  * eightbit    - address of result, will be set to 1 if the file contains
  *                any 8-bit bytes, 0 otherwise.
  *
@@ -112,12 +112,10 @@ char *m_strn(int value, unsigned int width);
  * program initialization
  *
  * argv0        - argv[0], presumably the program name
* read_context - 0: don't read context
*              - 1: read context, check nmh version, and issue warning message
*                   if non-existent or old
*              - 2: read context, don't check nmh version
  */
-int nmh_init(const char *argv0, int read_context);
+int nmh_init(const char *argv0, bool read_context, bool check_version);
 
 /*
  * Compares prior version of nmh with current version.  Returns 1
@@ -112,12 +112,10 @@ char *m_strn(int value, unsigned int width);
  *
  * argv0        - argv[0], presumably the program name
- * read_context - 0: don't read context
- *              - 1: read context, check nmh version, and issue warning message
- *                   if non-existent or old
- *              - 2: read context, don't check nmh version
+ * read_context - whether to read the context
+ * check_version - if read_context, whether to check the version, and issue warning message if non-existent or old
  */